@@ -49,8 +49,8 @@ public:
     /// Is the user currently signed into Crowdin?
     bool IsSignedIn() const;
 
-    /// Wrap relative Crowdin link to absolute URL
-    static std::string WrapLink(const std::string& page);
+    /// Wrap relative Crowdin URL to absolute URL with attribution
+    static std::string AttributeLink(std::string page);
 
     /**
         Authenticate with Crowdin.
@@ -71,6 +71,7 @@ public:
     {
         std::wstring name;
         std::wstring login;
+        std::string avatar;
     };
 
     /// Retrieve information about the current user asynchronously
@@ -81,48 +82,64 @@ public:
     {
         std::wstring name;
         std::string identifier;
-        bool downloadable;
+        int id;
     };
 
     /// Retrieve listing of projects accessible to the user
     dispatch::future<std::vector<ProjectListing>> GetUserProjects();
 
+    /// File information
+    struct FileInfo
+    {
+        std::string title;
+        std::string fileName, dirName, branchName;
+        std::string fullPath;
+        int id, dirId, branchId;
+    };
+
     /// Project detailed information
     struct ProjectInfo
     {
         std::wstring name;
-        std::string identifier;
+        int id;
         std::vector<Language> languages;
-        std::vector<std::wstring> files;
+        std::vector<FileInfo> files;
     };
 
     /// Retrieve listing of projects accessible to the user
-    dispatch::future<ProjectInfo> GetProjectInfo(const std::string& project_id);
+    dispatch::future<ProjectInfo> GetProjectInfo(const int project_id);
 
     /// Asynchronously download specific Crowdin file into @a output_file.
-    dispatch::future<void> DownloadFile(const std::string& project_id,
-                                        const std::wstring& file,
+    dispatch::future<void> DownloadFile(int project_id,
                                         const Language& lang,
+                                        int file_id,
+                                        const std::string& file_extension,
+                                        bool forceExportAsXliff,
                                         const std::wstring& output_file);
 
     /// Asynchronously upload specific Crowdin file data.
-    dispatch::future<void> UploadFile(const std::string& project_id,
-                                      const std::wstring& file,
+    dispatch::future<void> UploadFile(int project_id,
                                       const Language& lang,
+                                      int file_id,
+                                      const std::string& file_extension,
                                       const std::string& file_content);
 
 private:
     CrowdinClient();
     ~CrowdinClient();
 
+    // Initialize m_api for use with given authorization; must be called before use
+    void InitWithAuthToken(const std::string& authToken);
+
     void SignInIfAuthorized();
-    void SetToken(const std::string& token);
     void SaveAndSetToken(const std::string& token);
+    std::string GetValidToken() const;
 
     class crowdin_http_client;
-    std::unique_ptr<crowdin_http_client> m_api;
 
+    std::unique_ptr<crowdin_http_client> m_api;
     std::shared_ptr<dispatch::promise<void>> m_authCallback;
+    std::string m_authCallbackExpectedState;
 
     static CrowdinClient *ms_instance;
 };
