@@ -35,8 +35,7 @@ class WelcomeScreenBase : public wxPanel
 protected:
     WelcomeScreenBase(wxWindow *parent);
 
-    wxFont m_fntHeader, m_fntNorm, m_fntSub;
-    wxColour m_clrHeader, m_clrNorm, m_clrSub;
+    wxFont m_fntHeader;
 };
 
 /// Content view for initially opened Poedit, without a file
@@ -51,7 +50,7 @@ public:
 class EmptyPOScreenPanel : public WelcomeScreenBase
 {
 public:
-    EmptyPOScreenPanel(PoeditFrame *parent);
+    EmptyPOScreenPanel(PoeditFrame *parent, bool isGettext);
 };
 
 
